@@ -49,7 +49,7 @@ DeinterlaceQuality::DeinterlaceQuality(TQWidget* filterDialog, TQWidget *parent,
   grid->setSpacing(5);
   grid->setMargin(5);
 
-  m_qualitySlider = new TQSlider( Qt::Vertical, mainWidget );
+  m_qualitySlider = new TQSlider( TQt::Vertical, mainWidget );
   m_qualitySlider->setRange(0, 5);
   m_qualitySlider->setSteps(1, 1);
   m_qualitySlider->setTickmarks(TQSlider::Right);
@@ -75,12 +75,12 @@ DeinterlaceQuality::DeinterlaceQuality(TQWidget* filterDialog, TQWidget *parent,
 
   m_customBox = new TQCheckBox(i18n("User defined"), mainWidget);
   grid->addMultiCellWidget(m_customBox, 6, 6, 0, 1);
-  connect(m_customBox, TQT_SIGNAL(toggled(bool)), this, TQT_SLOT(slotCustomBoxToggled(bool)));
+  connect(m_customBox, TQ_SIGNAL(toggled(bool)), this, TQ_SLOT(slotCustomBoxToggled(bool)));
 
   m_customConfigButton = new KPushButton(i18n("Configure tvtime Deinterlace Plugin..."), mainWidget);
   m_customConfigButton->setSizePolicy(TQSizePolicy (TQSizePolicy::Minimum, TQSizePolicy::Fixed));
   grid->addWidget(m_customConfigButton, 7, 1);
-  connect(m_customConfigButton, TQT_SIGNAL(clicked()), filterDialog, TQT_SLOT(show()));
+  connect(m_customConfigButton, TQ_SIGNAL(clicked()), filterDialog, TQ_SLOT(show()));
 
   TQLabel* note = new TQLabel(i18n("* <i>May require a patched 2.4 kernel (like RedHat one) or 2.6 kernel.</i>"), mainWidget);
   note->setAlignment(TQLabel::WordBreak | TQLabel::AlignVCenter);
@@ -125,7 +125,7 @@ void DeinterlaceQuality::setQuality(uint qu)
     m_qualitySlider->setValue(qu-10);
     m_customBox->setChecked(true);
   }
-  connect(m_qualitySlider, TQT_SIGNAL(valueChanged(int)), this, TQT_SLOT(slotLevelChanged(int)));
+  connect(m_qualitySlider, TQ_SIGNAL(valueChanged(int)), this, TQ_SLOT(slotLevelChanged(int)));
 }     
 
 uint DeinterlaceQuality::getQuality() const
