@@ -32,7 +32,7 @@ class TQWidget;
 
 class ScreenshotPreview : public KPreviewWidgetBase
 {
-   Q_OBJECT
+   TQ_OBJECT
   
 public: 
   ScreenshotPreview(const TQImage& img, TQWidget *parent=0, const char *name=0);
