@@ -2090,7 +2090,7 @@ void VolumeSlider::wheelEvent(TQWheelEvent* e)
 		TQRect r = sliderRect();
 
 		if( r.contains( e->pos() ) || e->button() != LeftButton )
-			return FALSE;
+			return false;
 
 		int range = maxValue() - minValue();
 		int pos = (orientation() == Horizontal) ? e->pos().x() : e->pos().y();
@@ -2101,11 +2101,11 @@ void VolumeSlider::wheelEvent(TQWheelEvent* e)
 			value = maxValue() - (value - minValue());
 
 		setValue(value);
-		return TRUE;
+		return true;
 	}
 	else
 	{
-		return FALSE;
+		return false;
 	}
 }*/
 
