@@ -396,7 +396,7 @@ KMultiTabBarButton::KMultiTabBarButton(const TQPixmap& pic,const TQString& text,
 	setFixedWidth(24);
 	m_id=id;
 	TQToolTip::add(this,text);
-	connect(this,TQT_SIGNAL(clicked()),this,TQT_SLOT(slotClicked()));
+	connect(this,TQ_SIGNAL(clicked()),this,TQ_SLOT(slotClicked()));
 }
 
 KMultiTabBarButton::KMultiTabBarButton(const TQString& text, TQPopupMenu *popup,
@@ -411,7 +411,7 @@ KMultiTabBarButton::KMultiTabBarButton(const TQString& text, TQPopupMenu *popup,
 	setFixedWidth(24);
 	m_id=id;
 	TQToolTip::add(this,text);
-	connect(this,TQT_SIGNAL(clicked()),this,TQT_SLOT(slotClicked()));
+	connect(this,TQ_SIGNAL(clicked()),this,TQ_SLOT(slotClicked()));
 }
 
 KMultiTabBarButton::~KMultiTabBarButton() {
@@ -493,7 +493,7 @@ TQSize KMultiTabBarButton::sizeHint() const
             h = TQMAX(h, sz.height());
     }
 
-    return (style().tqsizeFromContents(TQStyle::CT_ToolButton, this, TQSize(w, h)).
+    return (style().sizeFromContents(TQStyle::CT_ToolButton, this, TQSize(w, h)).
             expandedTo(TQApplication::globalStrut()));
 }
 
@@ -905,7 +905,7 @@ void KMultiTabBar::updateSeparator() {
 int KMultiTabBar::appendTab(const TQPixmap &pic ,int id ,const TQString& text)
 {
 	m_internal->appendTab(pic,id,text);
-	connect( tab(id),TQT_SIGNAL(clicked(int)), this, TQT_SLOT(tabClicked(int)) );
+	connect( tab(id),TQ_SIGNAL(clicked(int)), this, TQ_SLOT(tabClicked(int)) );
 	return 0;
 }
 
